@@ -5,6 +5,9 @@ var searchData=
   ['mem_2eh_2',['mem.h',['../spa_2include_2spa_2debug_2mem_8h.html',1,'(Global Namespace)'],['../src_2pipewire_2mem_8h.html',1,'(Global Namespace)']]],
   ['meta_2eh_3',['meta.h',['../meta_8h.html',1,'']]],
   ['metadata_2eh_4',['metadata.h',['../metadata_8h.html',1,'']]],
-  ['module_2eh_5',['module.h',['../module_8h.html',1,'']]],
-  ['multiview_2eh_6',['multiview.h',['../multiview_8h.html',1,'']]]
+  ['mjpg_2dutils_2eh_5',['mjpg-utils.h',['../mjpg-utils_8h.html',1,'']]],
+  ['mjpg_2eh_6',['mjpg.h',['../mjpg_8h.html',1,'']]],
+  ['module_2eh_7',['module.h',['../module_8h.html',1,'']]],
+  ['mp3_2dutils_2eh_8',['mp3-utils.h',['../mp3-utils_8h.html',1,'']]],
+  ['multiview_2eh_9',['multiview.h',['../multiview_8h.html',1,'']]]
 ];
